Your task is to download the dataset that is presented in https://www.nature.com/articles/sdata201422. Please process the dataset in whatever format it is currently in into a CSV file with SMILES and the annotated target properties as additional columns. Please operate within the current folder.

hints:
- For downloading, please use the dedicated MCP file download tool
- To find a specific download link it might make sense to look at the HTML content of a page - e.g. with wget or curl
- If you encounter issues at any point, you may consider writing a python tool to execute programmatically